package com.ruoyi.web.controller.dragForm;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.entity.DragTableGroup;
import com.ruoyi.system.entity.vo.DragTableGroupVo;
import com.ruoyi.system.service.IDragTableGroupService;
import com.ruoyi.system.service.impl.DragTableServiceImpl;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * @author hmc
 * @date 2023-11-01 14:29
 * @Description:
 */
@RestController
@RequestMapping("/system/group")
@Api(value = "/system/group", description = "拖拽格组-接口")
public class DragTableGroupController extends BaseController {

    @Autowired
    private IDragTableGroupService dragTableGroupService;



    /**
     * 查询拖拽格组列表
     */
    @PreAuthorize("@ss.hasPermi('system:group:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询拖拽格组列表")
    public TableDataInfo list(DragTableGroup dragTableGroup)
    {
        startPage();
        List<DragTableGroup> list = dragTableGroupService.selectDragTableGroupList(dragTableGroup);
        return getDataTable(list);
    }

    /**
     * 导出拖拽格组列表
     */
    @PreAuthorize("@ss.hasPermi('system:group:export')")
    @Log(title = "拖拽格组", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出拖拽格组列表")
    public void export(HttpServletResponse response, DragTableGroup dragTableGroup)
    {
        List<DragTableGroup> list = dragTableGroupService.selectDragTableGroupList(dragTableGroup);
        ExcelUtil<DragTableGroup> util = new ExcelUtil<DragTableGroup>(DragTableGroup.class);
        util.exportExcel(response, list, "拖拽格组数据");
    }

    /**
     * 获取拖拽格组详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:group:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取拖拽格组详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(dragTableGroupService.selectDragTableGroupById(id));
    }

    /**
     * 获取拖拽格组详细信息
     */
    //@PreAuthorize("@ss.hasPermi('system:group:query')")
    //@GetMapping(value = "/{id}")
    //@ApiOperation(value = "获取拖拽格组详细信息")
    //public AjaxResult getInfo(@PathVariable("groupKey") Long groupKey)
    //{
    //    return success(dragTableGroupService.selectDragTableGroupById(id));
    //}


    /**
     * 新增拖拽格组
     */
    //@PreAuthorize("@ss.hasPermi('system:group:add')")
    //@Log(title = "拖拽格组", businessType = BusinessType.INSERT)
    //@PostMapping
    //@ApiOperation(value = "新增拖拽格组")
    //public AjaxResult add(@RequestBody DragTableGroup dragTableGroup)
    //{
    //    return toAjax(dragTableGroupService.insertDragTableGroup(dragTableGroup));
    //}

    //@PreAuthorize("@ss.hasPermi('system:group:add')")
    @Log(title = "拖拽格组", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增拖拽格组")
    public AjaxResult add(@RequestBody DragTableGroupVo dragTableGroupVo)
    {
        return toAjax(dragTableGroupService.insertDragTableGroup(dragTableGroupVo));
    }

    /**
     * 修改拖拽格组
     */
    @PreAuthorize("@ss.hasPermi('system:group:edit')")
    @Log(title = "拖拽格组", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改拖拽格组")
    public AjaxResult edit(@RequestBody DragTableGroup dragTableGroup)
    {
        return toAjax(dragTableGroupService.updateDragTableGroup(dragTableGroup));
    }

    /**
     * 删除拖拽格组
     */
    @PreAuthorize("@ss.hasPermi('system:group:remove')")
    @Log(title = "拖拽格组", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除拖拽格组")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(dragTableGroupService.deleteDragTableGroupByIds(ids));
    }
}
